Fat32DirectoryEntry

Struct Fat32DirectoryEntry 

#[repr(C, packed(1))]
pub struct Fat32DirectoryEntry { pub name: [u8; 11], pub attributes: u8, pub nt_reserved: u8, pub creation_time_tenths: u8, pub creation_time: u16, pub creation_date: u16, pub last_access_date: u16, pub cluster_high: u16, pub modification_time: u16, pub modification_date: u16, pub cluster_low: u16, pub file_size: u32, }
FAT32 Directory Entry structure

This structure represents a single directory entry in a FAT32 directory. Each entry is exactly 32 bytes.

Fields

name: [u8; 11]

Filename (8.3 format, padded with spaces)

attributes: u8

File attributes

nt_reserved: u8

Reserved for Windows NT

creation_time_tenths: u8

Creation time (tenths of a second)

creation_time: u16

Creation time

creation_date: u16

Creation date

last_access_date: u16

Last access date

cluster_high: u16

High 16 bits of cluster number

modification_time: u16

Last modification time

modification_date: u16

Last modification date

cluster_low: u16

Low 16 bits of cluster number

file_size: u32

File size in bytes

Implementations

Source

impl Fat32DirectoryEntry

pub fn is_free(&self) -> bool

Check if this entry is free (available for use)

pub fn is_last(&self) -> bool

Check if this is the last entry in the directory

pub fn is_long_filename(&self) -> bool

Check if this is a long filename entry

pub fn cluster(&self) -> u32

Get the starting cluster number

pub fn set_cluster(&mut self, cluster: u32)

Set the starting cluster number

pub fn update_cluster_and_size(&mut self, cluster: u32, size: u32)

Update only the cluster and file size fields (preserves SFN and other metadata)

pub fn is_directory(&self) -> bool

Check if this is a directory

pub fn is_file(&self) -> bool

Check if this is a regular file

pub fn is_volume_label(&self) -> bool

Check if this is a volume label

pub fn filename(&self) -> String

Get the filename as a string (8.3 format)

fn parse_filename(name: &[u8; 11]) -> String

Parse 8.3 filename format

pub fn new_file(name: &str, cluster: u32, size: u32) -> Self

Create a new directory entry

pub fn new_directory(name: &str, cluster: u32) -> Self

Create a new directory entry for a directory

fn set_name(&mut self, name: [u8; 11])

Set the filename (8.3 format) - expects properly formatted SFN bytes

pub fn generate_sfn(name: &str, numeric_tail: u32) -> [u8; 11]

Generate proper 8.3 Short File Name (SFN) from a long filename

fn is_valid_sfn_char(c: u8) -> bool

Check if a character is valid for SFN